@@ -1,7 +1,10 @@
 #pragma once
 
+#include <QTextEdit>
+
 #include "helpers/qownnotesmarkdownhighlighter.h"
 #include "libraries/qmarkdowntextedit/qmarkdowntextedit.h"
+#include "services/markdownlspclient.h"
 class MainWindow;
 class QOwnSpellChecker;
 
@@ -24,7 +27,7 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     ~QOwnNotesMarkdownTextEdit() override;
 
     void setStyles();
-    void openUrl(const QString &urlString) override;
+    void openUrl(const QString &urlString, bool openInNewTab) override;
     //    void setViewportMargins(int left, int top, int right, int bottom);
     void setPaperMargins(int width = -1);
     int modifyFontSize(FontModificationMode mode);
@@ -102,6 +105,9 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
 
     void updateIgnoredClickUrlRegexps();
 
+    void setMarkdownLspDocumentPath(const QString &filePath, const QString &text);
+    void closeMarkdownLspDocument();
+
    public slots:
     /**
      * Called when AI autocomplete is completed
@@ -123,6 +129,7 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     bool eventFilter(QObject *obj, QEvent *event) override;
     void keyPressEvent(QKeyEvent *e) override;
     void focusInEvent(QFocusEvent *e) override;
+    bool viewportEvent(QEvent *event) override;
 
    private:
     /// @param in is true if zoom-in, false otherwise
@@ -156,12 +163,29 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
      */
     void acceptAiAutocompleteSuggestion();
 
+    void applyMarkdownLspSettings();
+    void scheduleMarkdownLspChange();
+    void sendMarkdownLspChange();
+    void showMarkdownLspCompletions(int requestId, const QStringList &items);
+    void showMarkdownLspDiagnostics(const QString &uri,
+                                    const QVector<MarkdownLspClient::Diagnostic> &diagnostics);
+    void applyMarkdownLspDiagnosticsSelections();
+
     bool _isSpellCheckingDisabled = false;
     QString _aiAutocompleteSuggestion;
     int _aiAutocompletePosition = -1;
     QTimer *_aiAutocompleteTimer = nullptr;
     bool _isInsertingAiSuggestion = false;
 
+    MarkdownLspClient *_markdownLspClient = nullptr;
+    QTimer *_markdownLspChangeTimer = nullptr;
+    QString _markdownLspUri;
+    QString _markdownLspPendingText;
+    int _markdownLspVersion = 0;
+    int _markdownLspCompletionRequestId = -1;
+    bool _markdownLspEnabled = false;
+    QList<QTextEdit::ExtraSelection> _markdownLspDiagnosticsSelections;
+
     // Static pointer to the currently active editor for AI autocomplete
     static QOwnNotesMarkdownTextEdit *_activeAutocompleteEditor;
 };
